@@ -39,13 +39,13 @@ SetPolygonLimits <- function(poly.names=NULL, poly.data=NULL, poly.crop=NULL,
   # Open GUI
 
   tclServiceMode(FALSE)
-  tt <- tktoplevel(padx=0, pady=0)
+  tt <- tktoplevel()
 
   if (!is.null(parent)) {
     tkwm.transient(tt, parent)
-    tmp <- unlist(strsplit(as.character(tkwm.geometry(parent)), "\\+"))
-    tkwm.geometry(tt, paste("+", as.integer(tmp[2]) + 25,
-                            "+", as.integer(tmp[3]) + 25, sep=""))
+    geo <- unlist(strsplit(as.character(tkwm.geometry(parent)), "\\+"))
+    tkwm.geometry(tt, paste("+", as.integer(geo[2]) + 25,
+                            "+", as.integer(geo[3]) + 25, sep=""))
   }
 
   tktitle(tt) <- "Polygon Limits"
@@ -54,24 +54,23 @@ SetPolygonLimits <- function(poly.names=NULL, poly.data=NULL, poly.crop=NULL,
 
   # Frame 0
 
-  frame0 <- tkframe(tt, relief="flat", padx=0, pady=0)
+  frame0 <- tkframe(tt, relief="flat")
 
   frame0.but.1 <- ttkbutton(frame0, width=12, text="OK",
                             command=SaveNames)
   frame0.but.2 <- ttkbutton(frame0, width=12, text="Cancel",
                             command=function() tclvalue(tt.done.var) <- 1)
 
-  tkgrid(frame0.but.1, frame0.but.2)
+  tkgrid(frame0.but.1, frame0.but.2, pady=c(15, 10))
 
-  tkgrid.configure(frame0.but.1, sticky="e", padx=c(4, 0), pady=c(5, 8))
-  tkgrid.configure(frame0.but.2, sticky="w", padx=c(4, 8), pady=c(5, 8),
-                   rowspan=2)
+  tkgrid.configure(frame0.but.1, sticky="e", padx=c(0, 4))
+  tkgrid.configure(frame0.but.2, sticky="w", padx=c(0, 10), rowspan=2)
 
   tkpack(frame0, side="bottom", anchor="e")
 
   # Frame 1
 
-  frame1 <- ttkframe(tt, relief="flat", borderwidth=5, padding=8)
+  frame1 <- ttkframe(tt, relief="flat")
 
   frame1.lab.1.1 <- tklabel(frame1, text="Boundary defining data limits")
   frame1.lab.2.1 <- tklabel(frame1, text="Crop region for interpolated surface")
@@ -91,15 +90,15 @@ SetPolygonLimits <- function(poly.names=NULL, poly.data=NULL, poly.crop=NULL,
   if (!is.null(poly.crop))
     tcl(frame1.box.2.2, "current", match(poly.crop, poly.names) - 1)
 
-  tkgrid(frame1.lab.1.1, frame1.box.1.2, pady=0)
-  tkgrid(frame1.lab.2.1, frame1.box.2.2, pady=5)
+  tkgrid(frame1.lab.1.1, frame1.box.1.2, pady=c(10, 4))
+  tkgrid(frame1.lab.2.1, frame1.box.2.2)
 
   tkgrid.configure(frame1.lab.1.1, frame1.lab.2.1, sticky="e")
   tkgrid.configure(frame1.box.1.2, frame1.box.2.2, sticky="we")
 
   tkgrid.columnconfigure(frame1, 1, weight=1, minsize=25)
 
-  tkpack(frame1, fill="x", expand=TRUE, padx=2, pady=2)
+  tkpack(frame1, fill="x", expand=TRUE, padx=10)
 
   # GUI control
 
