@@ -25,11 +25,14 @@ ViewData <- function(d, column.names=NULL, column.units=NULL,
 
     if (is.null(matched.cells)) {
       n <- ncol(d) - 1L
-      fixed <- as.logical(as.integer(tclvalue(fixed.var)))
-      perl <- as.logical(as.integer(tclvalue(perl.var)))
 
-      matched.idxs <- grep(pattern, t(d[-1L, -1L]), fixed=fixed, perl=perl,
-                           ignore.case=FALSE, useBytes=FALSE, invert=FALSE)
+      case  <- as.logical(as.integer(tclvalue(case.var)))
+      perl  <- as.logical(as.integer(tclvalue(perl.var)))
+      fixed <- as.logical(as.integer(tclvalue(fixed.var)))
+
+      matched.idxs <- suppressWarnings(grep(pattern, t(d[-1L, -1L]),
+                                       fixed=fixed, perl=perl, ignore.case=case,
+                                       useBytes=FALSE, invert=FALSE))
 
       if (length(matched.idxs) == 0L) {
         msg <- paste("Search string \'", pattern, "\' not found.", sep="")
@@ -220,8 +223,9 @@ ViewData <- function(d, column.names=NULL, column.units=NULL,
   table.var   <- tclArray()
   line.no.var <- tclVar()
   pattern.var <- tclVar()
-  fixed.var   <- tclVar(1)
+  fixed.var   <- tclVar(0)
   perl.var    <- tclVar(0)
+  case.var    <- tclVar(0)
   tt.done.var <- tclVar(0)
 
   # Open GUI
@@ -287,13 +291,16 @@ ViewData <- function(d, column.names=NULL, column.units=NULL,
   frame1.but.2.3 <- ttkbutton(frame1, width=4, text="Goto",
                               command=GotoLine)
 
-  frame1.chk.1.5 <- ttkcheckbutton(frame1, variable=fixed.var, text="Fixed",
+  frame1.chk.1.5 <- ttkcheckbutton(frame1, variable=case.var,
+                                   text="Ignore case",
                                    command=function() matched.cells <<- NULL)
   frame1.chk.1.6 <- ttkcheckbutton(frame1, variable=perl.var, text="Perl",
                                    command=function() matched.cells <<- NULL)
+  frame1.chk.1.7 <- ttkcheckbutton(frame1, variable=fixed.var, text="Fixed",
+                                   command=function() matched.cells <<- NULL)
 
   tkgrid(frame1.lab.1.1, frame1.ent.1.2, frame1.but.1.3, frame1.but.1.4,
-         frame1.chk.1.5, frame1.chk.1.6, pady=c(0, 4))
+         frame1.chk.1.5, frame1.chk.1.6, frame1.chk.1.7, pady=c(0, 4))
   tkgrid(frame1.lab.2.1, frame1.ent.2.2, frame1.but.2.3)
 
   tkgrid.configure(frame1.ent.1.2, frame1.ent.2.2, padx=c(0, 2))
@@ -302,8 +309,8 @@ ViewData <- function(d, column.names=NULL, column.units=NULL,
   tkgrid.configure(frame1.but.1.3, padx=c(0, 2))
 
   tkgrid.configure(frame1.but.2.3, columnspan=2, sticky="we")
-  tkgrid.configure(frame1.chk.1.5, padx=c(4, 0))
-  tkgrid.configure(frame1.chk.1.6, padx=c(2, 10))
+  tkgrid.configure(frame1.chk.1.5, frame1.chk.1.6, padx=c(4, 0))
+  tkgrid.configure(frame1.chk.1.7, padx=c(4, 10))
 
   tkpack(frame1, side="bottom", anchor="nw", padx=c(10, 0))
 
@@ -358,7 +365,7 @@ ViewData <- function(d, column.names=NULL, column.units=NULL,
   tcl(frame2.tbl, "tag", "col", "rowtitles", 0)
   tktag.configure(frame2.tbl, "rowtitles", anchor="ne", justify="right")
 
-  tag.cols <- c(numeric.columns, posix.columns)
+  tag.cols <- which(numeric.columns | posix.columns)
   if (length(tag.cols) > 0) {
     for (j in tag.cols)
       tcl(frame2.tbl, "tag", "col", "numeric", j)
